@@ -818,7 +818,7 @@ class Account(ModelSQL, ModelView):
                             res[name][account_id] += deferral[name]
             else:
                 with Transaction().set_context(fiscalyear=fiscalyear.id,
-                        date=None, dates=None):
+                        date=None, periods=None):
                     res2 = self.get_credit_debit(ids, names)
                 for account_id in ids:
                     for name in names:
@@ -856,6 +856,7 @@ class Account(ModelSQL, ModelView):
             default = {}
         default['left'] = 0
         default['right'] = 0
+        default.setdefault('deferrals', [])
         res = super(Account, self).copy(ids, default=default)
         self._rebuild_tree('parent', None, 0)
         return res
